@@ -267,9 +267,9 @@ class nl80211cmd(genlmsg):
         ('NL80211_ATTR_DTIM_PERIOD', 'hex'),
         ('NL80211_ATTR_BEACON_HEAD', 'hex'),
         ('NL80211_ATTR_BEACON_TAIL', 'hex'),
-        ('NL80211_ATTR_STA_AID', 'hex'),
+        ('NL80211_ATTR_STA_AID', 'uint16'),
         ('NL80211_ATTR_STA_FLAGS', 'hex'),
-        ('NL80211_ATTR_STA_LISTEN_INTERVAL', 'hex'),
+        ('NL80211_ATTR_STA_LISTEN_INTERVAL', 'uint16'),
         ('NL80211_ATTR_STA_SUPPORTED_RATES', 'hex'),
         ('NL80211_ATTR_STA_VLAN', 'hex'),
         ('NL80211_ATTR_STA_INFO', 'STAInfo'),
@@ -422,7 +422,7 @@ class nl80211cmd(genlmsg):
         ('NL80211_ATTR_RADAR_EVENT', 'hex'),
         ('NL80211_ATTR_EXT_CAPA', 'array(uint8)'),
         ('NL80211_ATTR_EXT_CAPA_MASK', 'array(uint8)'),
-        ('NL80211_ATTR_STA_CAPABILITY', 'hex'),
+        ('NL80211_ATTR_STA_CAPABILITY', 'uint16'),
         ('NL80211_ATTR_STA_EXT_CAPABILITY', 'hex'),
         ('NL80211_ATTR_PROTOCOL_FEATURES', 'hex'),
         ('NL80211_ATTR_SPLIT_WIPHY_DUMP', 'hex'),
@@ -1587,7 +1587,7 @@ class MarshalNl80211(Marshal):
 class NL80211(GenericNetlinkSocket):
     def __init__(self, *args, **kwargs):
         GenericNetlinkSocket.__init__(self, *args, **kwargs)
-        self.marshal = MarshalNl80211()
+        self.set_marshal(MarshalNl80211())
 
     def bind(self, groups=0, **kwarg):
         GenericNetlinkSocket.bind(
